# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from alphausblue.api.ripple import org_pb2 as api_dot_ripple_dot_org__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from alphausblue.org.v1 import org_pb2 as org_dot_v1_dot_org__pb2


class OrganizationStub(object):
    """Organization service definition.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateOrg = channel.unary_unary(
                '/blueapi.org.v1.Organization/CreateOrg',
                request_serializer=org_dot_v1_dot_org__pb2.CreateOrgRequest.SerializeToString,
                response_deserializer=org_dot_v1_dot_org__pb2.CreateOrgResponse.FromString,
                )
        self.SendVerification = channel.unary_unary(
                '/blueapi.org.v1.Organization/SendVerification',
                request_serializer=org_dot_v1_dot_org__pb2.SendVerificationRequest.SerializeToString,
                response_deserializer=api_dot_ripple_dot_org__pb2.Org.FromString,
                )
        self.VerifyOrg = channel.unary_unary(
                '/blueapi.org.v1.Organization/VerifyOrg',
                request_serializer=org_dot_v1_dot_org__pb2.VerifyOrgRequest.SerializeToString,
                response_deserializer=api_dot_ripple_dot_org__pb2.Org.FromString,
                )
        self.GetOrg = channel.unary_unary(
                '/blueapi.org.v1.Organization/GetOrg',
                request_serializer=org_dot_v1_dot_org__pb2.GetOrgRequest.SerializeToString,
                response_deserializer=api_dot_ripple_dot_org__pb2.Org.FromString,
                )
        self.UpdateMetadata = channel.unary_unary(
                '/blueapi.org.v1.Organization/UpdateMetadata',
                request_serializer=org_dot_v1_dot_org__pb2.UpdateMetadataRequest.SerializeToString,
                response_deserializer=api_dot_ripple_dot_org__pb2.Org.FromString,
                )
        self.UpdatePassword = channel.unary_unary(
                '/blueapi.org.v1.Organization/UpdatePassword',
                request_serializer=org_dot_v1_dot_org__pb2.UpdatePasswordRequest.SerializeToString,
                response_deserializer=api_dot_ripple_dot_org__pb2.Org.FromString,
                )
        self.DeleteOrg = channel.unary_unary(
                '/blueapi.org.v1.Organization/DeleteOrg',
                request_serializer=org_dot_v1_dot_org__pb2.DeleteOrgRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class OrganizationServicer(object):
    """Organization service definition.
    """

    def CreateOrg(self, request, context):
        """Creates the organization account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendVerification(self, request, context):
        """Sends (or resends) the verification email. Only valid for unverified
        organizations. The verification key will be valid for a day.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VerifyOrg(self, request, context):
        """Verifies an organization using the key received from the verification email.
        The verification key is only valid for a day.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrg(self, request, context):
        """Gets information about the caller's organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateMetadata(self, request, context):
        """Updates organization metadata. See [https://alphauslabs.github.io/blueapi/]
        for the list of supported attributes.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdatePassword(self, request, context):
        """Updates the organization password.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteOrg(self, request, context):
        """Deletes the organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_OrganizationServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateOrg': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOrg,
                    request_deserializer=org_dot_v1_dot_org__pb2.CreateOrgRequest.FromString,
                    response_serializer=org_dot_v1_dot_org__pb2.CreateOrgResponse.SerializeToString,
            ),
            'SendVerification': grpc.unary_unary_rpc_method_handler(
                    servicer.SendVerification,
                    request_deserializer=org_dot_v1_dot_org__pb2.SendVerificationRequest.FromString,
                    response_serializer=api_dot_ripple_dot_org__pb2.Org.SerializeToString,
            ),
            'VerifyOrg': grpc.unary_unary_rpc_method_handler(
                    servicer.VerifyOrg,
                    request_deserializer=org_dot_v1_dot_org__pb2.VerifyOrgRequest.FromString,
                    response_serializer=api_dot_ripple_dot_org__pb2.Org.SerializeToString,
            ),
            'GetOrg': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrg,
                    request_deserializer=org_dot_v1_dot_org__pb2.GetOrgRequest.FromString,
                    response_serializer=api_dot_ripple_dot_org__pb2.Org.SerializeToString,
            ),
            'UpdateMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateMetadata,
                    request_deserializer=org_dot_v1_dot_org__pb2.UpdateMetadataRequest.FromString,
                    response_serializer=api_dot_ripple_dot_org__pb2.Org.SerializeToString,
            ),
            'UpdatePassword': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdatePassword,
                    request_deserializer=org_dot_v1_dot_org__pb2.UpdatePasswordRequest.FromString,
                    response_serializer=api_dot_ripple_dot_org__pb2.Org.SerializeToString,
            ),
            'DeleteOrg': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteOrg,
                    request_deserializer=org_dot_v1_dot_org__pb2.DeleteOrgRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'blueapi.org.v1.Organization', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Organization(object):
    """Organization service definition.
    """

    @staticmethod
    def CreateOrg(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.org.v1.Organization/CreateOrg',
            org_dot_v1_dot_org__pb2.CreateOrgRequest.SerializeToString,
            org_dot_v1_dot_org__pb2.CreateOrgResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendVerification(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.org.v1.Organization/SendVerification',
            org_dot_v1_dot_org__pb2.SendVerificationRequest.SerializeToString,
            api_dot_ripple_dot_org__pb2.Org.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def VerifyOrg(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.org.v1.Organization/VerifyOrg',
            org_dot_v1_dot_org__pb2.VerifyOrgRequest.SerializeToString,
            api_dot_ripple_dot_org__pb2.Org.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrg(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.org.v1.Organization/GetOrg',
            org_dot_v1_dot_org__pb2.GetOrgRequest.SerializeToString,
            api_dot_ripple_dot_org__pb2.Org.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.org.v1.Organization/UpdateMetadata',
            org_dot_v1_dot_org__pb2.UpdateMetadataRequest.SerializeToString,
            api_dot_ripple_dot_org__pb2.Org.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdatePassword(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.org.v1.Organization/UpdatePassword',
            org_dot_v1_dot_org__pb2.UpdatePasswordRequest.SerializeToString,
            api_dot_ripple_dot_org__pb2.Org.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteOrg(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.org.v1.Organization/DeleteOrg',
            org_dot_v1_dot_org__pb2.DeleteOrgRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from grpc.aio import (
    ClientCallDetails,
    Metadata)

from .interceptor import create

def _header_adder_interceptor(header, value):
    """
    Function that creates an interceptor that adds headers to the request metadata
    @param header: The name of the header to be added
    @param value: The value of the header to be added
    @returns: An interceptor that can be inserted into an intercept_channel that will
        operate the function on every GRPC request
    """

    # First, create the intercept call that we can inject into the interceptor
    def intercept_call(client_call_details, request_iterator, request_streaming, response_streaming):

        # First, create the list of metadata. If we have metadata on the client call
        # details then get those values and convert them to a list
        metadata = client_call_details.metadata
        if not metadata:
            metadata = Metadata()

        # Next, create a new tuple from the header and value and add it to the metadata
        metadata[header] = value

        # Now, create a new client call details from the existing client call details and
        # return it, along with the request iterator and a (None) post-processor
        client_call_details = ClientCallDetails(
            client_call_details.method, client_call_details.timeout, metadata,
            client_call_details.credentials, client_call_details.wait_for_ready)
        return client_call_details, request_iterator, None

    # Create the interceptor with the function and return it
    return create(intercept_call)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: org/v1/org.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from alphausblue.api.ripple import org_pb2 as api_dot_ripple_dot_org__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='org/v1/org.proto',
  package='blueapi.org.v1',
  syntax='proto3',
  serialized_options=b'\n\025cloud.alphaus.api.orgB\010OrgProtoZ\"github.com/alphauslabs/blueapi/org\222A\343\t\022\301\t\n\032Alphaus Blue API reference\022\203\010Alphaus provides an API for interacting with its services. Blue API is a RESTful API that can be accessed by an HTTP client such as `curl`, or any HTTP library which is part of most modern programming languages. This API reference is autogenerated from [protocol buffers](https://developers.google.com/protocol-buffers) defined in this [repository](https://github.com/alphauslabs/blueapi), together with our supported [client libraries](https://alphauslabs.github.io/blueapi/sdks/). See the official [documentation](https://alphauslabs.github.io/blueapi/) for more information.\n\nYou may encounter the following feature maturity indicators:\n- **(BETA)** - New or experimental features, subject to changes; and\n- **(Deprecated)** - Outdated or replaced features.\n\nSome endpoints, especially those that return lists of resources, have streaming responses; newline-separated stream of \342\200\234chunks\342\200\235. Each chunk is an envelope that can contain either a response message or an error. Only the last chunk will include an error, if any.\";\n\021Alphaus: Blue API\022&https://alphauslabs.github.io/blueapi/*W\n\033License: Apache License 2.0\0228https://github.com/alphauslabs/blueapi/blob/main/LICENSE2\007v0.beta\032\021api.alphaus.cloud\"\007/m/blue*\001\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10org/v1/org.proto\x12\x0e\x62lueapi.org.v1\x1a\x14\x61pi/ripple/org.proto\x1a\x1cgoogle/api/annotations.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\"H\n\x10\x43reateOrgRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"K\n\x11\x43reateOrgResponse\x12$\n\x03org\x18\x01 \x01(\x0b\x32\x17.blueapi.api.ripple.Org\x12\x10\n\x08password\x18\x02 \x01(\t\"\x19\n\x17SendVerificationRequest\"\x1f\n\x10VerifyOrgRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\"\x0f\n\rGetOrgRequest\"3\n\x15UpdateMetadataRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"A\n\x15UpdatePasswordRequest\x12\x13\n\x0boldPassword\x18\x01 \x01(\t\x12\x13\n\x0bnewPassword\x18\x02 \x01(\t\"\x12\n\x10\x44\x65leteOrgRequest2\xef\x06\n\x0cOrganization\x12\x64\n\tCreateOrg\x12 .blueapi.org.v1.CreateOrgRequest\x1a!.blueapi.org.v1.CreateOrgResponse\"\x12\x82\xd3\xe4\x93\x02\x0c\"\x07/org/v1:\x01*\x12v\n\x10SendVerification\x12\'.blueapi.org.v1.SendVerificationRequest\x1a\x17.blueapi.api.ripple.Org\" \x82\xd3\xe4\x93\x02\x1a\"\x18/org/v1:sendVerification\x12\x61\n\tVerifyOrg\x12 .blueapi.org.v1.VerifyOrgRequest\x1a\x17.blueapi.api.ripple.Org\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/org/v1:verify:\x01*\x12Q\n\x06GetOrg\x12\x1d.blueapi.org.v1.GetOrgRequest\x1a\x17.blueapi.api.ripple.Org\"\x0f\x82\xd3\xe4\x93\x02\t\x12\x07/org/v1\x12m\n\x0eUpdateMetadata\x12%.blueapi.org.v1.UpdateMetadataRequest\x1a\x17.blueapi.api.ripple.Org\"\x1b\x82\xd3\xe4\x93\x02\x15\x1a\x10/org/v1/metadata:\x01*\x12k\n\x0eUpdatePassword\x12%.blueapi.org.v1.UpdatePasswordRequest\x1a\x17.blueapi.api.ripple.Org\"\x19\x82\xd3\xe4\x93\x02\x13\x1a\x0e/org/v1/passwd:\x01*\x12V\n\tDeleteOrg\x12 .blueapi.org.v1.DeleteOrgRequest\x1a\x16.google.protobuf.Empty\"\x0f\x82\xd3\xe4\x93\x02\t*\x07/org/v1\x1a\x96\x01\x92\x41\x92\x01\x12\x43(BETA) Organization API. Base URL: https://api.alphaus.cloud/m/blue\x1aK\n\x12Service definition\x12\x35https://github.com/alphauslabs/blueapi/tree/main/org/B\xac\n\n\x15\x63loud.alphaus.api.orgB\x08OrgProtoZ\"github.com/alphauslabs/blueapi/org\x92\x41\xe3\t\x12\xc1\t\n\x1a\x41lphaus Blue API reference\x12\x83\x08\x41lphaus provides an API for interacting with its services. Blue API is a RESTful API that can be accessed by an HTTP client such as `curl`, or any HTTP library which is part of most modern programming languages. This API reference is autogenerated from [protocol buffers](https://developers.google.com/protocol-buffers) defined in this [repository](https://github.com/alphauslabs/blueapi), together with our supported [client libraries](https://alphauslabs.github.io/blueapi/sdks/). See the official [documentation](https://alphauslabs.github.io/blueapi/) for more information.\n\nYou may encounter the following feature maturity indicators:\n- **(BETA)** - New or experimental features, subject to changes; and\n- **(Deprecated)** - Outdated or replaced features.\n\nSome endpoints, especially those that return lists of resources, have streaming responses; newline-separated stream of \xe2\x80\x9c\x63hunks\xe2\x80\x9d. Each chunk is an envelope that can contain either a response message or an error. Only the last chunk will include an error, if any.\";\n\x11\x41lphaus: Blue API\x12&https://alphauslabs.github.io/blueapi/*W\n\x1bLicense: Apache License 2.0\x12\x38https://github.com/alphauslabs/blueapi/blob/main/LICENSE2\x07v0.beta\x1a\x11\x61pi.alphaus.cloud\"\x07/m/blue*\x01\x02\x62\x06proto3'
  ,
  dependencies=[api_dot_ripple_dot_org__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,protoc__gen__openapiv2_dot_options_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])




_CREATEORGREQUEST = _descriptor.Descriptor(
  name='CreateOrgRequest',
  full_name='blueapi.org.v1.CreateOrgRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='email', full_name='blueapi.org.v1.CreateOrgRequest.email', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='blueapi.org.v1.CreateOrgRequest.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='blueapi.org.v1.CreateOrgRequest.password', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=165,
  serialized_end=237,
)


_CREATEORGRESPONSE = _descriptor.Descriptor(
  name='CreateOrgResponse',
  full_name='blueapi.org.v1.CreateOrgResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='org', full_name='blueapi.org.v1.CreateOrgResponse.org', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='blueapi.org.v1.CreateOrgResponse.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=239,
  serialized_end=314,
)


_SENDVERIFICATIONREQUEST = _descriptor.Descriptor(
  name='SendVerificationRequest',
  full_name='blueapi.org.v1.SendVerificationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=316,
  serialized_end=341,
)


_VERIFYORGREQUEST = _descriptor.Descriptor(
  name='VerifyOrgRequest',
  full_name='blueapi.org.v1.VerifyOrgRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='blueapi.org.v1.VerifyOrgRequest.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=343,
  serialized_end=374,
)


_GETORGREQUEST = _descriptor.Descriptor(
  name='GetOrgRequest',
  full_name='blueapi.org.v1.GetOrgRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=376,
  serialized_end=391,
)


_UPDATEMETADATAREQUEST = _descriptor.Descriptor(
  name='UpdateMetadataRequest',
  full_name='blueapi.org.v1.UpdateMetadataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='blueapi.org.v1.UpdateMetadataRequest.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='blueapi.org.v1.UpdateMetadataRequest.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=393,
  serialized_end=444,
)


_UPDATEPASSWORDREQUEST = _descriptor.Descriptor(
  name='UpdatePasswordRequest',
  full_name='blueapi.org.v1.UpdatePasswordRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oldPassword', full_name='blueapi.org.v1.UpdatePasswordRequest.oldPassword', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='newPassword', full_name='blueapi.org.v1.UpdatePasswordRequest.newPassword', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=446,
  serialized_end=511,
)


_DELETEORGREQUEST = _descriptor.Descriptor(
  name='DeleteOrgRequest',
  full_name='blueapi.org.v1.DeleteOrgRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=513,
  serialized_end=531,
)

_CREATEORGRESPONSE.fields_by_name['org'].message_type = api_dot_ripple_dot_org__pb2._ORG
DESCRIPTOR.message_types_by_name['CreateOrgRequest'] = _CREATEORGREQUEST
DESCRIPTOR.message_types_by_name['CreateOrgResponse'] = _CREATEORGRESPONSE
DESCRIPTOR.message_types_by_name['SendVerificationRequest'] = _SENDVERIFICATIONREQUEST
DESCRIPTOR.message_types_by_name['VerifyOrgRequest'] = _VERIFYORGREQUEST
DESCRIPTOR.message_types_by_name['GetOrgRequest'] = _GETORGREQUEST
DESCRIPTOR.message_types_by_name['UpdateMetadataRequest'] = _UPDATEMETADATAREQUEST
DESCRIPTOR.message_types_by_name['UpdatePasswordRequest'] = _UPDATEPASSWORDREQUEST
DESCRIPTOR.message_types_by_name['DeleteOrgRequest'] = _DELETEORGREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateOrgRequest = _reflection.GeneratedProtocolMessageType('CreateOrgRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEORGREQUEST,
  '__module__' : 'org.v1.org_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.org.v1.CreateOrgRequest)
  })
_sym_db.RegisterMessage(CreateOrgRequest)

CreateOrgResponse = _reflection.GeneratedProtocolMessageType('CreateOrgResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEORGRESPONSE,
  '__module__' : 'org.v1.org_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.org.v1.CreateOrgResponse)
  })
_sym_db.RegisterMessage(CreateOrgResponse)

SendVerificationRequest = _reflection.GeneratedProtocolMessageType('SendVerificationRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENDVERIFICATIONREQUEST,
  '__module__' : 'org.v1.org_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.org.v1.SendVerificationRequest)
  })
_sym_db.RegisterMessage(SendVerificationRequest)

VerifyOrgRequest = _reflection.GeneratedProtocolMessageType('VerifyOrgRequest', (_message.Message,), {
  'DESCRIPTOR' : _VERIFYORGREQUEST,
  '__module__' : 'org.v1.org_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.org.v1.VerifyOrgRequest)
  })
_sym_db.RegisterMessage(VerifyOrgRequest)

GetOrgRequest = _reflection.GeneratedProtocolMessageType('GetOrgRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETORGREQUEST,
  '__module__' : 'org.v1.org_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.org.v1.GetOrgRequest)
  })
_sym_db.RegisterMessage(GetOrgRequest)

UpdateMetadataRequest = _reflection.GeneratedProtocolMessageType('UpdateMetadataRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMETADATAREQUEST,
  '__module__' : 'org.v1.org_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.org.v1.UpdateMetadataRequest)
  })
_sym_db.RegisterMessage(UpdateMetadataRequest)

UpdatePasswordRequest = _reflection.GeneratedProtocolMessageType('UpdatePasswordRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPASSWORDREQUEST,
  '__module__' : 'org.v1.org_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.org.v1.UpdatePasswordRequest)
  })
_sym_db.RegisterMessage(UpdatePasswordRequest)

DeleteOrgRequest = _reflection.GeneratedProtocolMessageType('DeleteOrgRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEORGREQUEST,
  '__module__' : 'org.v1.org_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.org.v1.DeleteOrgRequest)
  })
_sym_db.RegisterMessage(DeleteOrgRequest)


DESCRIPTOR._options = None

_ORGANIZATION = _descriptor.ServiceDescriptor(
  name='Organization',
  full_name='blueapi.org.v1.Organization',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\222A\222\001\022C(BETA) Organization API. Base URL: https://api.alphaus.cloud/m/blue\032K\n\022Service definition\0225https://github.com/alphauslabs/blueapi/tree/main/org/',
  create_key=_descriptor._internal_create_key,
  serialized_start=534,
  serialized_end=1413,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateOrg',
    full_name='blueapi.org.v1.Organization.CreateOrg',
    index=0,
    containing_service=None,
    input_type=_CREATEORGREQUEST,
    output_type=_CREATEORGRESPONSE,
    serialized_options=b'\202\323\344\223\002\014\"\007/org/v1:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendVerification',
    full_name='blueapi.org.v1.Organization.SendVerification',
    index=1,
    containing_service=None,
    input_type=_SENDVERIFICATIONREQUEST,
    output_type=api_dot_ripple_dot_org__pb2._ORG,
    serialized_options=b'\202\323\344\223\002\032\"\030/org/v1:sendVerification',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='VerifyOrg',
    full_name='blueapi.org.v1.Organization.VerifyOrg',
    index=2,
    containing_service=None,
    input_type=_VERIFYORGREQUEST,
    output_type=api_dot_ripple_dot_org__pb2._ORG,
    serialized_options=b'\202\323\344\223\002\023\"\016/org/v1:verify:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetOrg',
    full_name='blueapi.org.v1.Organization.GetOrg',
    index=3,
    containing_service=None,
    input_type=_GETORGREQUEST,
    output_type=api_dot_ripple_dot_org__pb2._ORG,
    serialized_options=b'\202\323\344\223\002\t\022\007/org/v1',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateMetadata',
    full_name='blueapi.org.v1.Organization.UpdateMetadata',
    index=4,
    containing_service=None,
    input_type=_UPDATEMETADATAREQUEST,
    output_type=api_dot_ripple_dot_org__pb2._ORG,
    serialized_options=b'\202\323\344\223\002\025\032\020/org/v1/metadata:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdatePassword',
    full_name='blueapi.org.v1.Organization.UpdatePassword',
    index=5,
    containing_service=None,
    input_type=_UPDATEPASSWORDREQUEST,
    output_type=api_dot_ripple_dot_org__pb2._ORG,
    serialized_options=b'\202\323\344\223\002\023\032\016/org/v1/passwd:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteOrg',
    full_name='blueapi.org.v1.Organization.DeleteOrg',
    index=6,
    containing_service=None,
    input_type=_DELETEORGREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\t*\007/org/v1',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ORGANIZATION)

DESCRIPTOR.services_by_name['Organization'] = _ORGANIZATION

# @@protoc_insertion_point(module_scope)



from grpc import (
    composite_channel_credentials,
    ssl_channel_credentials,
    access_token_call_credentials)

from grpc.aio import (
    Channel,
    secure_channel)

from .header_interceptor import _header_adder_interceptor
from .session import Session

BLUE = "blue"
BLUE_ENDPOINT = "blue.alphaus.cloud:8443"
BLUE_ENDPOINT_NEXT = "bluenext.alphaus.cloud:8443"

def grpc_client_connection(svc: str = None, target: str = None, session: Session = None) -> Channel:
    """
    Create a new GRPC client connection from a service name, target endpoint and session
    @param svc: The name of the service to which we're trying to connect (ex. blue)
    @param target: The endpoint, associated with the service, to which the connection
        should direct its GRPC requests
    @param session: The session to associate with the connection. This object will be
        used to authenticate with the service
    """

    # First, set the session and target to default values if they weren't provided
    session = session if session else Session()
    target = target if target else BLUE_ENDPOINT
    
    # Next, get the access token from the session and then embed
    # it into credentials we can send to the GRPC service
    token = session.access_token()
    credentials = composite_channel_credentials(
        ssl_channel_credentials(),
        access_token_call_credentials(token))

    # Now, create a secure channel from the target and credentials
    if svc:
        conn = secure_channel(
            target = target, 
            credentials = credentials, 
            options = (('grpc.enable_http_proxy', 0),),
            interceptors = [
                _header_adder_interceptor("service-name", svc),
                _header_adder_interceptor("x-agent", "blue-sdk-python")])
    else:
        conn = secure_channel(target = target, credentials = credentials)
    
    # Return the connection
    return conn


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/aws/cost.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='api/aws/cost.proto',
  package='blueapi.api.aws',
  syntax='proto3',
  serialized_options=b'\n\035cloud.alphaus.blueapi.api.awsB\017ApiAwsCostProtoZ*github.com/alphauslabs/blue-sdk-go/api/aws',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12\x61pi/aws/cost.proto\x12\x0f\x62lueapi.api.aws\"\xfa\x05\n\x04\x43ost\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12\x0f\n\x07groupId\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x1d \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x03 \x01(\t\x12\x13\n\x0bproductCode\x18\x04 \x01(\t\x12\x13\n\x0bserviceCode\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x0c\n\x04zone\x18\x07 \x01(\t\x12\x11\n\tusageType\x18\x08 \x01(\t\x12\x14\n\x0cinstanceType\x18\t \x01(\t\x12\x11\n\toperation\x18\n \x01(\t\x12\x11\n\tinvoiceId\x18\x0b \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x0c \x01(\t\x12\x12\n\nresourceId\x18\r \x01(\t\x12-\n\x04tags\x18\x0e \x03(\x0b\x32\x1f.blueapi.api.aws.Cost.TagsEntry\x12\x41\n\x0e\x63ostCategories\x18\x0f \x03(\x0b\x32).blueapi.api.aws.Cost.CostCategoriesEntry\x12\r\n\x05usage\x18\x10 \x01(\x01\x12\x0c\n\x04\x63ost\x18\x11 \x01(\x01\x12\x15\n\runblendedCost\x18\x1b \x01(\x01\x12\x14\n\x0c\x62\x61seCurrency\x18\x12 \x01(\t\x12\x14\n\x0c\x65xchangeRate\x18\x13 \x01(\x01\x12\x12\n\ntargetCost\x18\x14 \x01(\x01\x12\x1b\n\x13targetUnblendedCost\x18\x1c \x01(\x01\x12\x16\n\x0etargetCurrency\x18\x15 \x01(\t\x12\x15\n\reffectiveCost\x18\x17 \x01(\x01\x12\x1b\n\x13targetEffectiveCost\x18\x18 \x01(\x01\x12\x15\n\ramortizedCost\x18\x19 \x01(\x01\x12\x1b\n\x13targetAmortizedCost\x18\x1a \x01(\x01\x12\r\n\x05tagId\x18\x16 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x35\n\x13\x43ostCategoriesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\\\n\x1d\x63loud.alphaus.blueapi.api.awsB\x0f\x41piAwsCostProtoZ*github.com/alphauslabs/blue-sdk-go/api/awsb\x06proto3'
)




_COST_TAGSENTRY = _descriptor.Descriptor(
  name='TagsEntry',
  full_name='blueapi.api.aws.Cost.TagsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='blueapi.api.aws.Cost.TagsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='blueapi.api.aws.Cost.TagsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=704,
  serialized_end=747,
)

_COST_COSTCATEGORIESENTRY = _descriptor.Descriptor(
  name='CostCategoriesEntry',
  full_name='blueapi.api.aws.Cost.CostCategoriesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='blueapi.api.aws.Cost.CostCategoriesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='blueapi.api.aws.Cost.CostCategoriesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=749,
  serialized_end=802,
)

_COST = _descriptor.Descriptor(
  name='Cost',
  full_name='blueapi.api.aws.Cost',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='blueapi.api.aws.Cost.account', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groupId', full_name='blueapi.api.aws.Cost.groupId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='blueapi.api.aws.Cost.type', index=2,
      number=29, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date', full_name='blueapi.api.aws.Cost.date', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='productCode', full_name='blueapi.api.aws.Cost.productCode', index=4,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serviceCode', full_name='blueapi.api.aws.Cost.serviceCode', index=5,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='region', full_name='blueapi.api.aws.Cost.region', index=6,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone', full_name='blueapi.api.aws.Cost.zone', index=7,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usageType', full_name='blueapi.api.aws.Cost.usageType', index=8,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instanceType', full_name='blueapi.api.aws.Cost.instanceType', index=9,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation', full_name='blueapi.api.aws.Cost.operation', index=10,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invoiceId', full_name='blueapi.api.aws.Cost.invoiceId', index=11,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='blueapi.api.aws.Cost.description', index=12,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resourceId', full_name='blueapi.api.aws.Cost.resourceId', index=13,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='blueapi.api.aws.Cost.tags', index=14,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='costCategories', full_name='blueapi.api.aws.Cost.costCategories', index=15,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage', full_name='blueapi.api.aws.Cost.usage', index=16,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cost', full_name='blueapi.api.aws.Cost.cost', index=17,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unblendedCost', full_name='blueapi.api.aws.Cost.unblendedCost', index=18,
      number=27, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseCurrency', full_name='blueapi.api.aws.Cost.baseCurrency', index=19,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchangeRate', full_name='blueapi.api.aws.Cost.exchangeRate', index=20,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetCost', full_name='blueapi.api.aws.Cost.targetCost', index=21,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetUnblendedCost', full_name='blueapi.api.aws.Cost.targetUnblendedCost', index=22,
      number=28, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetCurrency', full_name='blueapi.api.aws.Cost.targetCurrency', index=23,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='effectiveCost', full_name='blueapi.api.aws.Cost.effectiveCost', index=24,
      number=23, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetEffectiveCost', full_name='blueapi.api.aws.Cost.targetEffectiveCost', index=25,
      number=24, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amortizedCost', full_name='blueapi.api.aws.Cost.amortizedCost', index=26,
      number=25, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetAmortizedCost', full_name='blueapi.api.aws.Cost.targetAmortizedCost', index=27,
      number=26, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tagId', full_name='blueapi.api.aws.Cost.tagId', index=28,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_COST_TAGSENTRY, _COST_COSTCATEGORIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40,
  serialized_end=802,
)

_COST_TAGSENTRY.containing_type = _COST
_COST_COSTCATEGORIESENTRY.containing_type = _COST
_COST.fields_by_name['tags'].message_type = _COST_TAGSENTRY
_COST.fields_by_name['costCategories'].message_type = _COST_COSTCATEGORIESENTRY
DESCRIPTOR.message_types_by_name['Cost'] = _COST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Cost = _reflection.GeneratedProtocolMessageType('Cost', (_message.Message,), {

  'TagsEntry' : _reflection.GeneratedProtocolMessageType('TagsEntry', (_message.Message,), {
    'DESCRIPTOR' : _COST_TAGSENTRY,
    '__module__' : 'api.aws.cost_pb2'
    # @@protoc_insertion_point(class_scope:blueapi.api.aws.Cost.TagsEntry)
    })
  ,

  'CostCategoriesEntry' : _reflection.GeneratedProtocolMessageType('CostCategoriesEntry', (_message.Message,), {
    'DESCRIPTOR' : _COST_COSTCATEGORIESENTRY,
    '__module__' : 'api.aws.cost_pb2'
    # @@protoc_insertion_point(class_scope:blueapi.api.aws.Cost.CostCategoriesEntry)
    })
  ,
  'DESCRIPTOR' : _COST,
  '__module__' : 'api.aws.cost_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.aws.Cost)
  })
_sym_db.RegisterMessage(Cost)
_sym_db.RegisterMessage(Cost.TagsEntry)
_sym_db.RegisterMessage(Cost.CostCategoriesEntry)


DESCRIPTOR._options = None
_COST_TAGSENTRY._options = None
_COST_COSTCATEGORIESENTRY._options = None
# @@protoc_insertion_point(module_scope)



from setuptools import find_namespace_packages, setup

setup(
    name = "alphausblue",
    author = "Alphaus KK",
    author_email = "dev@alphaus.cloud",
    description = "Alphaus KK's Blue API for Python",
    url = "https://github.com/alphauslabs/blue-sdk-python",
    version = "1.0.15",
    packages = find_namespace_packages(),
    install_requires = [
        "google-api-core>=2.0.1",
        "google-api-python-client",
        "google-auth>=2.2.0",
        "google-auth-httplib2",
        "googleapis-common-protos",
        "grpc-gateway-protoc-gen-openapiv2>=0.1.0",
        "grpcio>=1.41.0",
        "httplib2",
        "protobuf>=3.18.0",
        "requests"
    ],
    python_requires = ">=3.6",
    options = {
        "bdist_wheel": {
            "universal": True
        }
    }
)


import asyncio

from alphausblue.connection.conn import grpc_client_connection
from alphausblue.iam.v1.iam_pb2 import WhoAmIRequest
from alphausblue.iam.v1.iam_pb2_grpc import IamStub

async def main():

    # First, create the connection from a session
    conn = grpc_client_connection(svc = "blue")

    # Next, connect to the organization service with the connection
    stub = IamStub(conn)

    # Finally, create an organization
    resp = await stub.WhoAmI(WhoAmIRequest())
    print(resp)

if __name__ == "__main__":
    asyncio.run(main())


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from alphausblue.kvstore.v1 import kvstore_pb2 as kvstore_dot_v1_dot_kvstore__pb2


class KvStoreStub(object):
    """KvStore service definition.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Scan = channel.unary_stream(
                '/blueapi.kvstore.v1.KvStore/Scan',
                request_serializer=kvstore_dot_v1_dot_kvstore__pb2.ScanRequest.SerializeToString,
                response_deserializer=kvstore_dot_v1_dot_kvstore__pb2.KeyValue.FromString,
                )
        self.Read = channel.unary_unary(
                '/blueapi.kvstore.v1.KvStore/Read',
                request_serializer=kvstore_dot_v1_dot_kvstore__pb2.ReadRequest.SerializeToString,
                response_deserializer=kvstore_dot_v1_dot_kvstore__pb2.KeyValue.FromString,
                )
        self.Write = channel.unary_unary(
                '/blueapi.kvstore.v1.KvStore/Write',
                request_serializer=kvstore_dot_v1_dot_kvstore__pb2.KeyValue.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.Delete = channel.unary_unary(
                '/blueapi.kvstore.v1.KvStore/Delete',
                request_serializer=kvstore_dot_v1_dot_kvstore__pb2.DeleteRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class KvStoreServicer(object):
    """KvStore service definition.
    """

    def Scan(self, request, context):
        """Scans key:value data from your store.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Read(self, request, context):
        """Reads a key:value data from your store.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Write(self, request, context):
        """Writes a new (or update an existing) key:value data in your store.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes a key:value data from your store.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_KvStoreServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Scan': grpc.unary_stream_rpc_method_handler(
                    servicer.Scan,
                    request_deserializer=kvstore_dot_v1_dot_kvstore__pb2.ScanRequest.FromString,
                    response_serializer=kvstore_dot_v1_dot_kvstore__pb2.KeyValue.SerializeToString,
            ),
            'Read': grpc.unary_unary_rpc_method_handler(
                    servicer.Read,
                    request_deserializer=kvstore_dot_v1_dot_kvstore__pb2.ReadRequest.FromString,
                    response_serializer=kvstore_dot_v1_dot_kvstore__pb2.KeyValue.SerializeToString,
            ),
            'Write': grpc.unary_unary_rpc_method_handler(
                    servicer.Write,
                    request_deserializer=kvstore_dot_v1_dot_kvstore__pb2.KeyValue.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=kvstore_dot_v1_dot_kvstore__pb2.DeleteRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'blueapi.kvstore.v1.KvStore', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class KvStore(object):
    """KvStore service definition.
    """

    @staticmethod
    def Scan(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/blueapi.kvstore.v1.KvStore/Scan',
            kvstore_dot_v1_dot_kvstore__pb2.ScanRequest.SerializeToString,
            kvstore_dot_v1_dot_kvstore__pb2.KeyValue.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Read(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.kvstore.v1.KvStore/Read',
            kvstore_dot_v1_dot_kvstore__pb2.ReadRequest.SerializeToString,
            kvstore_dot_v1_dot_kvstore__pb2.KeyValue.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Write(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.kvstore.v1.KvStore/Write',
            kvstore_dot_v1_dot_kvstore__pb2.KeyValue.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.kvstore.v1.KvStore/Delete',
            kvstore_dot_v1_dot_kvstore__pb2.DeleteRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from alphausblue.api import apiclient_pb2 as api_dot_apiclient__pb2
from alphausblue.api import rbac_pb2 as api_dot_rbac__pb2
from alphausblue.api import user_pb2 as api_dot_user__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from alphausblue.iam.v1 import iam_pb2 as iam_dot_v1_dot_iam__pb2


class IamStub(object):
    """IAM service definition.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.WhoAmI = channel.unary_unary(
                '/blueapi.iam.v1.Iam/WhoAmI',
                request_serializer=iam_dot_v1_dot_iam__pb2.WhoAmIRequest.SerializeToString,
                response_deserializer=api_dot_user__pb2.User.FromString,
                )
        self.ListUsers = channel.unary_stream(
                '/blueapi.iam.v1.Iam/ListUsers',
                request_serializer=iam_dot_v1_dot_iam__pb2.ListUsersRequest.SerializeToString,
                response_deserializer=api_dot_user__pb2.User.FromString,
                )
        self.GetUser = channel.unary_unary(
                '/blueapi.iam.v1.Iam/GetUser',
                request_serializer=iam_dot_v1_dot_iam__pb2.GetUserRequest.SerializeToString,
                response_deserializer=api_dot_user__pb2.User.FromString,
                )
        self.CreateUser = channel.unary_unary(
                '/blueapi.iam.v1.Iam/CreateUser',
                request_serializer=iam_dot_v1_dot_iam__pb2.CreateUserRequest.SerializeToString,
                response_deserializer=api_dot_user__pb2.User.FromString,
                )
        self.DeleteUser = channel.unary_unary(
                '/blueapi.iam.v1.Iam/DeleteUser',
                request_serializer=iam_dot_v1_dot_iam__pb2.DeleteUserRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListApiClients = channel.unary_stream(
                '/blueapi.iam.v1.Iam/ListApiClients',
                request_serializer=iam_dot_v1_dot_iam__pb2.ListApiClientsRequest.SerializeToString,
                response_deserializer=api_dot_apiclient__pb2.ApiClient.FromString,
                )
        self.CreateApiClient = channel.unary_unary(
                '/blueapi.iam.v1.Iam/CreateApiClient',
                request_serializer=iam_dot_v1_dot_iam__pb2.CreateApiClientRequest.SerializeToString,
                response_deserializer=api_dot_apiclient__pb2.ApiClient.FromString,
                )
        self.DeleteApiClient = channel.unary_unary(
                '/blueapi.iam.v1.Iam/DeleteApiClient',
                request_serializer=iam_dot_v1_dot_iam__pb2.DeleteApiClientRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListPermissions = channel.unary_unary(
                '/blueapi.iam.v1.Iam/ListPermissions',
                request_serializer=iam_dot_v1_dot_iam__pb2.ListPermissionsRequest.SerializeToString,
                response_deserializer=iam_dot_v1_dot_iam__pb2.ListPermissionsResponse.FromString,
                )
        self.ListRoles = channel.unary_unary(
                '/blueapi.iam.v1.Iam/ListRoles',
                request_serializer=iam_dot_v1_dot_iam__pb2.ListRolesRequest.SerializeToString,
                response_deserializer=iam_dot_v1_dot_iam__pb2.ListRolesResponse.FromString,
                )
        self.CreateRole = channel.unary_unary(
                '/blueapi.iam.v1.Iam/CreateRole',
                request_serializer=iam_dot_v1_dot_iam__pb2.CreateRoleRequest.SerializeToString,
                response_deserializer=api_dot_rbac__pb2.Role.FromString,
                )
        self.UpdateRole = channel.unary_unary(
                '/blueapi.iam.v1.Iam/UpdateRole',
                request_serializer=iam_dot_v1_dot_iam__pb2.UpdateRoleRequest.SerializeToString,
                response_deserializer=api_dot_rbac__pb2.Role.FromString,
                )
        self.DeleteRole = channel.unary_unary(
                '/blueapi.iam.v1.Iam/DeleteRole',
                request_serializer=iam_dot_v1_dot_iam__pb2.DeleteRoleRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListUserRoleMappings = channel.unary_unary(
                '/blueapi.iam.v1.Iam/ListUserRoleMappings',
                request_serializer=iam_dot_v1_dot_iam__pb2.ListUserRoleMappingsRequest.SerializeToString,
                response_deserializer=iam_dot_v1_dot_iam__pb2.ListUserRoleMappingsResponse.FromString,
                )
        self.CreateUserRoleMapping = channel.unary_unary(
                '/blueapi.iam.v1.Iam/CreateUserRoleMapping',
                request_serializer=iam_dot_v1_dot_iam__pb2.CreateUserRoleMappingRequest.SerializeToString,
                response_deserializer=iam_dot_v1_dot_iam__pb2.CreateUserRoleMappingResponse.FromString,
                )
        self.UpdateUserRoleMapping = channel.unary_unary(
                '/blueapi.iam.v1.Iam/UpdateUserRoleMapping',
                request_serializer=iam_dot_v1_dot_iam__pb2.UpdateUserRoleMappingRequest.SerializeToString,
                response_deserializer=iam_dot_v1_dot_iam__pb2.UpdateUserRoleMappingResponse.FromString,
                )
        self.ListIpFilters = channel.unary_stream(
                '/blueapi.iam.v1.Iam/ListIpFilters',
                request_serializer=iam_dot_v1_dot_iam__pb2.ListIpFiltersRequest.SerializeToString,
                response_deserializer=iam_dot_v1_dot_iam__pb2.IpFilter.FromString,
                )
        self.CreateIpFilter = channel.unary_unary(
                '/blueapi.iam.v1.Iam/CreateIpFilter',
                request_serializer=iam_dot_v1_dot_iam__pb2.CreateIpFilterRequest.SerializeToString,
                response_deserializer=iam_dot_v1_dot_iam__pb2.IpFilter.FromString,
                )
        self.DeleteIpFilter = channel.unary_unary(
                '/blueapi.iam.v1.Iam/DeleteIpFilter',
                request_serializer=iam_dot_v1_dot_iam__pb2.DeleteIpFilterRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class IamServicer(object):
    """IAM service definition.
    """

    def WhoAmI(self, request, context):
        """Gets user information about the caller. This call includes all of the user metadata.
        See [https://alphauslabs.github.io/blueapi/] for the list of supported attributes.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUsers(self, request, context):
        """Lists all subusers.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUser(self, request, context):
        """Gets subuser information. This call includes all of the subuser metadata. See
        [https://alphauslabs.github.io/blueapi/] for the list of supported attributes.
        If the `{name}` parameter is `me` or `-`, returns the caller information, which
        is equivalent to `WhoAmI()` or `GET:/iam/v*/whoami`.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateUser(self, request, context):
        """Creates a subuser.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteUser(self, request, context):
        """Deletes a subuser.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListApiClients(self, request, context):
        """Lists all API clients belonging to the caller.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateApiClient(self, request, context):
        """Creates an API client for the caller.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteApiClient(self, request, context):
        """Deletes an API client belonging to the caller.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPermissions(self, request, context):
        """Lists all permissions based on the input's scope. For reference, supported
        permissions can be found on [https://github.com/mobingi/rbac-permissions].
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListRoles(self, request, context):
        """Lists all available roles.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateRole(self, request, context):
        """Creates a role. If your `permissions` list contains an `Admin` entry, all other
        entries will be discarded except `Admin`. Roles are root user-level. That means
        all roles created by the root user, or any subuser that has permissions to
        create roles, are available to all subusers.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateRole(self, request, context):
        """Updates a role. If role name is different, rename mapped role name.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteRole(self, request, context):
        """Deletes a role. Deleting a role will also remove all mappings.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUserRoleMappings(self, request, context):
        """Lists roles attached to the caller or the input.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateUserRoleMapping(self, request, context):
        """Maps roles to a subuser. You can only map (or attach) up to 5 roles to a user per namespace.
        There is no limit for filtering rules per user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUserRoleMapping(self, request, context):
        """Updates user-to-role mappings. You can only map (or attach) up to 5 roles to a user per namespace.
        There is no limit for filtering rules per user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListIpFilters(self, request, context):
        """Lists all IP filters. At the moment, this API is only available for root users.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateIpFilter(self, request, context):
        """Creates an IP filter item for IP blacklisting or whitelisting. At the moment,
        this API is only available for root users.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteIpFilter(self, request, context):
        """Deletes an IP filter item. At the moment, this API is only available for root users.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_IamServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'WhoAmI': grpc.unary_unary_rpc_method_handler(
                    servicer.WhoAmI,
                    request_deserializer=iam_dot_v1_dot_iam__pb2.WhoAmIRequest.FromString,
                    response_serializer=api_dot_user__pb2.User.SerializeToString,
            ),
            'ListUsers': grpc.unary_stream_rpc_method_handler(
                    servicer.ListUsers,
                    request_deserializer=iam_dot_v1_dot_iam__pb2.ListUsersRequest.FromString,
                    response_serializer=api_dot_user__pb2.User.SerializeToString,
            ),
            'GetUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUser,
                    request_deserializer=iam_dot_v1_dot_iam__pb2.GetUserRequest.FromString,
                    response_serializer=api_dot_user__pb2.User.SerializeToString,
            ),
            'CreateUser': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateUser,
                    request_deserializer=iam_dot_v1_dot_iam__pb2.CreateUserRequest.FromString,
                    response_serializer=api_dot_user__pb2.User.SerializeToString,
            ),
            'DeleteUser': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteUser,
                    request_deserializer=iam_dot_v1_dot_iam__pb2.DeleteUserRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListApiClients': grpc.unary_stream_rpc_method_handler(
                    servicer.ListApiClients,
                    request_deserializer=iam_dot_v1_dot_iam__pb2.ListApiClientsRequest.FromString,
                    response_serializer=api_dot_apiclient__pb2.ApiClient.SerializeToString,
            ),
            'CreateApiClient': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateApiClient,
                    request_deserializer=iam_dot_v1_dot_iam__pb2.CreateApiClientRequest.FromString,
                    response_serializer=api_dot_apiclient__pb2.ApiClient.SerializeToString,
            ),
            'DeleteApiClient': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteApiClient,
                    request_deserializer=iam_dot_v1_dot_iam__pb2.DeleteApiClientRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListPermissions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPermissions,
                    request_deserializer=iam_dot_v1_dot_iam__pb2.ListPermissionsRequest.FromString,
                    response_serializer=iam_dot_v1_dot_iam__pb2.ListPermissionsResponse.SerializeToString,
            ),
            'ListRoles': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRoles,
                    request_deserializer=iam_dot_v1_dot_iam__pb2.ListRolesRequest.FromString,
                    response_serializer=iam_dot_v1_dot_iam__pb2.ListRolesResponse.SerializeToString,
            ),
            'CreateRole': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateRole,
                    request_deserializer=iam_dot_v1_dot_iam__pb2.CreateRoleRequest.FromString,
                    response_serializer=api_dot_rbac__pb2.Role.SerializeToString,
            ),
            'UpdateRole': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateRole,
                    request_deserializer=iam_dot_v1_dot_iam__pb2.UpdateRoleRequest.FromString,
                    response_serializer=api_dot_rbac__pb2.Role.SerializeToString,
            ),
            'DeleteRole': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteRole,
                    request_deserializer=iam_dot_v1_dot_iam__pb2.DeleteRoleRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListUserRoleMappings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUserRoleMappings,
                    request_deserializer=iam_dot_v1_dot_iam__pb2.ListUserRoleMappingsRequest.FromString,
                    response_serializer=iam_dot_v1_dot_iam__pb2.ListUserRoleMappingsResponse.SerializeToString,
            ),
            'CreateUserRoleMapping': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateUserRoleMapping,
                    request_deserializer=iam_dot_v1_dot_iam__pb2.CreateUserRoleMappingRequest.FromString,
                    response_serializer=iam_dot_v1_dot_iam__pb2.CreateUserRoleMappingResponse.SerializeToString,
            ),
            'UpdateUserRoleMapping': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUserRoleMapping,
                    request_deserializer=iam_dot_v1_dot_iam__pb2.UpdateUserRoleMappingRequest.FromString,
                    response_serializer=iam_dot_v1_dot_iam__pb2.UpdateUserRoleMappingResponse.SerializeToString,
            ),
            'ListIpFilters': grpc.unary_stream_rpc_method_handler(
                    servicer.ListIpFilters,
                    request_deserializer=iam_dot_v1_dot_iam__pb2.ListIpFiltersRequest.FromString,
                    response_serializer=iam_dot_v1_dot_iam__pb2.IpFilter.SerializeToString,
            ),
            'CreateIpFilter': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateIpFilter,
                    request_deserializer=iam_dot_v1_dot_iam__pb2.CreateIpFilterRequest.FromString,
                    response_serializer=iam_dot_v1_dot_iam__pb2.IpFilter.SerializeToString,
            ),
            'DeleteIpFilter': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteIpFilter,
                    request_deserializer=iam_dot_v1_dot_iam__pb2.DeleteIpFilterRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'blueapi.iam.v1.Iam', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Iam(object):
    """IAM service definition.
    """

    @staticmethod
    def WhoAmI(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.iam.v1.Iam/WhoAmI',
            iam_dot_v1_dot_iam__pb2.WhoAmIRequest.SerializeToString,
            api_dot_user__pb2.User.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/blueapi.iam.v1.Iam/ListUsers',
            iam_dot_v1_dot_iam__pb2.ListUsersRequest.SerializeToString,
            api_dot_user__pb2.User.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.iam.v1.Iam/GetUser',
            iam_dot_v1_dot_iam__pb2.GetUserRequest.SerializeToString,
            api_dot_user__pb2.User.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.iam.v1.Iam/CreateUser',
            iam_dot_v1_dot_iam__pb2.CreateUserRequest.SerializeToString,
            api_dot_user__pb2.User.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.iam.v1.Iam/DeleteUser',
            iam_dot_v1_dot_iam__pb2.DeleteUserRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListApiClients(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/blueapi.iam.v1.Iam/ListApiClients',
            iam_dot_v1_dot_iam__pb2.ListApiClientsRequest.SerializeToString,
            api_dot_apiclient__pb2.ApiClient.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateApiClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.iam.v1.Iam/CreateApiClient',
            iam_dot_v1_dot_iam__pb2.CreateApiClientRequest.SerializeToString,
            api_dot_apiclient__pb2.ApiClient.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteApiClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.iam.v1.Iam/DeleteApiClient',
            iam_dot_v1_dot_iam__pb2.DeleteApiClientRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPermissions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.iam.v1.Iam/ListPermissions',
            iam_dot_v1_dot_iam__pb2.ListPermissionsRequest.SerializeToString,
            iam_dot_v1_dot_iam__pb2.ListPermissionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListRoles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.iam.v1.Iam/ListRoles',
            iam_dot_v1_dot_iam__pb2.ListRolesRequest.SerializeToString,
            iam_dot_v1_dot_iam__pb2.ListRolesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateRole(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.iam.v1.Iam/CreateRole',
            iam_dot_v1_dot_iam__pb2.CreateRoleRequest.SerializeToString,
            api_dot_rbac__pb2.Role.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateRole(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.iam.v1.Iam/UpdateRole',
            iam_dot_v1_dot_iam__pb2.UpdateRoleRequest.SerializeToString,
            api_dot_rbac__pb2.Role.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteRole(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.iam.v1.Iam/DeleteRole',
            iam_dot_v1_dot_iam__pb2.DeleteRoleRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUserRoleMappings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.iam.v1.Iam/ListUserRoleMappings',
            iam_dot_v1_dot_iam__pb2.ListUserRoleMappingsRequest.SerializeToString,
            iam_dot_v1_dot_iam__pb2.ListUserRoleMappingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateUserRoleMapping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.iam.v1.Iam/CreateUserRoleMapping',
            iam_dot_v1_dot_iam__pb2.CreateUserRoleMappingRequest.SerializeToString,
            iam_dot_v1_dot_iam__pb2.CreateUserRoleMappingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateUserRoleMapping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.iam.v1.Iam/UpdateUserRoleMapping',
            iam_dot_v1_dot_iam__pb2.UpdateUserRoleMappingRequest.SerializeToString,
            iam_dot_v1_dot_iam__pb2.UpdateUserRoleMappingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListIpFilters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/blueapi.iam.v1.Iam/ListIpFilters',
            iam_dot_v1_dot_iam__pb2.ListIpFiltersRequest.SerializeToString,
            iam_dot_v1_dot_iam__pb2.IpFilter.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateIpFilter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.iam.v1.Iam/CreateIpFilter',
            iam_dot_v1_dot_iam__pb2.CreateIpFilterRequest.SerializeToString,
            iam_dot_v1_dot_iam__pb2.IpFilter.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteIpFilter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.iam.v1.Iam/DeleteIpFilter',
            iam_dot_v1_dot_iam__pb2.DeleteIpFilterRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from grpc.aio import (
    UnaryUnaryClientInterceptor,
    UnaryStreamClientInterceptor,
    StreamUnaryClientInterceptor,
    StreamStreamClientInterceptor)

class _GenericClientInterceptor(UnaryUnaryClientInterceptor,
                                UnaryStreamClientInterceptor,
                                StreamUnaryClientInterceptor,
                                StreamStreamClientInterceptor):
    """
    Creates a generic intercepter that can be injected into the
    channel so that actions will be performed with any and all
    GRPC requests performed on the connection
    """

    def __init__(self, interceptor_function):
        """
        Creates a new generic client interceptor from an interceptor function
        @param interceptor_function: A function that accepts client call details,
            a request iterator, whether or not the request was streamed and whether
            or not the response was streamed
        """
        self._fn = interceptor_function

    async def intercept_unary_unary(self, continuation, client_call_details, request):
        """
        Intercepts requests that take a unary request and return a unary response and
        runs the function on them
        @param continuation: The function that will be called to either operate the
            next interceptor or else to call the request function
        @param client_call_details: The details associated with the client call, including
            the method, timeout, metadata and credentials
        @param request: The request that will be sent to the GRCP endpoint
        @returns: The response from the GRPC endpoint
        """
        return await self._inercept_inner(continuation, client_call_details, iter((request,)), False, False)

    async def intercept_unary_stream(self, continuation, client_call_details, request):
        """
        Intercepts requests that take a unary request and return a stream response and
        runs the function on them
        @param continuation: The function that will be called to either operate the
            next interceptor or else to call the request function
        @param client_call_details: The details associated with the client call, including
            the method, timeout, metadata and credentials
        @param request: The request that will be sent to the GRCP endpoint
        @returns: The response from the GRPC endpoint
        """
        return await self._inercept_inner(continuation, client_call_details, iter((request,)), False, True)

    async def intercept_stream_unary(self, continuation, client_call_details, request_iterator):
        """
        Intercepts requests that take a stream request and return a unary response and
        runs the function on them
        @param continuation: The function that will be called to either operate the
            next interceptor or else to call the request function
        @param client_call_details: The details associated with the client call, including
            the method, timeout, metadata and credentials
        @param request: The request that will be sent to the GRCP endpoint
        @returns: The response from the GRPC endpoint
        """
        return await self._inercept_inner(continuation, client_call_details, request_iterator, True, False)

    async def intercept_stream_stream(self, continuation, client_call_details, request_iterator):
        """
        Intercepts requests that take a stream request and return a stream request and
        runs the function on them
        @param continuation: The function that will be called to either operate the
            next interceptor or else to call the request function
        @param client_call_details: The details associated with the client call, including
            the method, timeout, metadata and credentials
        @param request: The request that will be sent to the GRCP endpoint
        @returns: The response from the GRPC endpoint
        """
        return await self._inercept_inner(continuation, client_call_details, request_iterator, True, True)
    
    # Helper function that operates the interceptor based on common data between all interceptor functions
    async def _inercept_inner(self, continuation, client_call_details, request_iterator, 
        request_streaming, response_streaming):
    
        # First, get the new client call details, the new request iterator and the
        # post-process function from the interceptor function
        new_details, new_request_iterator, postprocess = self._fn(
            client_call_details, request_iterator, request_streaming, response_streaming)

        # Call the next function in the chain with the client call details and the
        # request iterator to get a response
        response_it = await continuation(new_details, new_request_iterator if request_streaming else next(new_request_iterator))
        
        # Inject the response into the post-response object if we have a post-process
        # function; otherwise, return the response
        return postprocess(response_it) if postprocess else response_it


def create(intercept_call):
    """
    Creates an interceptor from an interception function
    @param intercept_call: A function that accepts client call details, a 
        request iterator, whether or not the request was streamed and whether
        or not the response was streamed
    """
    return _GenericClientInterceptor(intercept_call)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/ripple/org.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='api/ripple/org.proto',
  package='blueapi.api.ripple',
  syntax='proto3',
  serialized_options=b'\n cloud.alphaus.blueapi.api.rippleB\021ApiRippleOrgProtoZ-github.com/alphauslabs/blue-sdk-go/api/ripple',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x14\x61pi/ripple/org.proto\x12\x12\x62lueapi.api.ripple\"\x8c\x01\n\x03Org\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x37\n\x08metadata\x18\x03 \x03(\x0b\x32%.blueapi.api.ripple.Org.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x64\n cloud.alphaus.blueapi.api.rippleB\x11\x41piRippleOrgProtoZ-github.com/alphauslabs/blue-sdk-go/api/rippleb\x06proto3'
)




_ORG_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='blueapi.api.ripple.Org.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='blueapi.api.ripple.Org.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='blueapi.api.ripple.Org.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=138,
  serialized_end=185,
)

_ORG = _descriptor.Descriptor(
  name='Org',
  full_name='blueapi.api.ripple.Org',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='blueapi.api.ripple.Org.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email', full_name='blueapi.api.ripple.Org.email', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='blueapi.api.ripple.Org.metadata', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ORG_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=185,
)

_ORG_METADATAENTRY.containing_type = _ORG
_ORG.fields_by_name['metadata'].message_type = _ORG_METADATAENTRY
DESCRIPTOR.message_types_by_name['Org'] = _ORG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Org = _reflection.GeneratedProtocolMessageType('Org', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _ORG_METADATAENTRY,
    '__module__' : 'api.ripple.org_pb2'
    # @@protoc_insertion_point(class_scope:blueapi.api.ripple.Org.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _ORG,
  '__module__' : 'api.ripple.org_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.ripple.Org)
  })
_sym_db.RegisterMessage(Org)
_sym_db.RegisterMessage(Org.MetadataEntry)


DESCRIPTOR._options = None
_ORG_METADATAENTRY._options = None
# @@protoc_insertion_point(module_scope)



import asyncio

from alphausblue.connection.conn import grpc_client_connection
from alphausblue.org.v1.org_pb2 import CreateOrgRequest
from alphausblue.org.v1.org_pb2_grpc import OrganizationStub

async def main():

    # First, create the connection from a session
    conn = grpc_client_connection(svc = "blue")

    # Next, connect to the organization service with the connection
    stub = OrganizationStub(conn)

    # Finally, create an organization
    resp = await stub.CreateOrg(CreateOrgRequest(
        email = "fake@email.ext",
        description = "This is an organization",
        password = "asdf243@#$gba@"))
    print(resp)

if __name__ == "__main__":
    asyncio.run(main())


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from alphausblue.admin.v1 import admin_pb2 as admin_dot_v1_dot_admin__pb2


class AdminStub(object):
    """Admin service definition.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListAccountGroups = channel.unary_stream(
                '/blueapi.admin.v1.Admin/ListAccountGroups',
                request_serializer=admin_dot_v1_dot_admin__pb2.ListAccountGroupsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_admin__pb2.ListAccountGroupsResponse.FromString,
                )
        self.GetAccountGroup = channel.unary_unary(
                '/blueapi.admin.v1.Admin/GetAccountGroup',
                request_serializer=admin_dot_v1_dot_admin__pb2.GetAccountGroupRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_admin__pb2.GetAccountGroupResponse.FromString,
                )


class AdminServicer(object):
    """Admin service definition.
    """

    def ListAccountGroups(self, request, context):
        """Lists all account groups.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccountGroup(self, request, context):
        """Gets an account group.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AdminServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListAccountGroups': grpc.unary_stream_rpc_method_handler(
                    servicer.ListAccountGroups,
                    request_deserializer=admin_dot_v1_dot_admin__pb2.ListAccountGroupsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_admin__pb2.ListAccountGroupsResponse.SerializeToString,
            ),
            'GetAccountGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccountGroup,
                    request_deserializer=admin_dot_v1_dot_admin__pb2.GetAccountGroupRequest.FromString,
                    response_serializer=admin_dot_v1_dot_admin__pb2.GetAccountGroupResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'blueapi.admin.v1.Admin', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Admin(object):
    """Admin service definition.
    """

    @staticmethod
    def ListAccountGroups(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/blueapi.admin.v1.Admin/ListAccountGroups',
            admin_dot_v1_dot_admin__pb2.ListAccountGroupsRequest.SerializeToString,
            admin_dot_v1_dot_admin__pb2.ListAccountGroupsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAccountGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.admin.v1.Admin/GetAccountGroup',
            admin_dot_v1_dot_admin__pb2.GetAccountGroupRequest.SerializeToString,
            admin_dot_v1_dot_admin__pb2.GetAccountGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/rbac.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='api/rbac.proto',
  package='blueapi.api',
  syntax='proto3',
  serialized_options=b'\n\031cloud.alphaus.blueapi.apiB\014ApiRbacProtoZ&github.com/alphauslabs/blue-sdk-go/api',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0e\x61pi/rbac.proto\x12\x0b\x62lueapi.api\"E\n\x06Policy\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x0e\n\x06\x65\x66\x66\x65\x63t\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x0e\n\x06values\x18\x04 \x03(\t\"[\n\nPermission\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x13\n\x0bpermissions\x18\x02 \x03(\t\x12%\n\x08policies\x18\x03 \x03(\x0b\x32\x13.blueapi.api.Policy\"c\n\x04Role\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x13\n\x0bpermissions\x18\x03 \x03(\t\x12%\n\x08policies\x18\x04 \x03(\x0b\x32\x13.blueapi.api.Policy\"e\n\x0fUserRoleMapping\x12\x10\n\x08rootUser\x18\x01 \x01(\t\x12\x0f\n\x07subUser\x18\x02 \x01(\t\x12\x11\n\tnamespace\x18\x03 \x01(\t\x12\x0c\n\x04role\x18\x04 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x05 \x01(\tBQ\n\x19\x63loud.alphaus.blueapi.apiB\x0c\x41piRbacProtoZ&github.com/alphauslabs/blue-sdk-go/apib\x06proto3'
)




_POLICY = _descriptor.Descriptor(
  name='Policy',
  full_name='blueapi.api.Policy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='blueapi.api.Policy.action', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='effect', full_name='blueapi.api.Policy.effect', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='blueapi.api.Policy.key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='blueapi.api.Policy.values', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31,
  serialized_end=100,
)


_PERMISSION = _descriptor.Descriptor(
  name='Permission',
  full_name='blueapi.api.Permission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='blueapi.api.Permission.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permissions', full_name='blueapi.api.Permission.permissions', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='policies', full_name='blueapi.api.Permission.policies', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=102,
  serialized_end=193,
)


_ROLE = _descriptor.Descriptor(
  name='Role',
  full_name='blueapi.api.Role',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='blueapi.api.Role.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='blueapi.api.Role.namespace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permissions', full_name='blueapi.api.Role.permissions', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='policies', full_name='blueapi.api.Role.policies', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=195,
  serialized_end=294,
)


_USERROLEMAPPING = _descriptor.Descriptor(
  name='UserRoleMapping',
  full_name='blueapi.api.UserRoleMapping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rootUser', full_name='blueapi.api.UserRoleMapping.rootUser', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subUser', full_name='blueapi.api.UserRoleMapping.subUser', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='blueapi.api.UserRoleMapping.namespace', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role', full_name='blueapi.api.UserRoleMapping.role', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='blueapi.api.UserRoleMapping.filter', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=296,
  serialized_end=397,
)

_PERMISSION.fields_by_name['policies'].message_type = _POLICY
_ROLE.fields_by_name['policies'].message_type = _POLICY
DESCRIPTOR.message_types_by_name['Policy'] = _POLICY
DESCRIPTOR.message_types_by_name['Permission'] = _PERMISSION
DESCRIPTOR.message_types_by_name['Role'] = _ROLE
DESCRIPTOR.message_types_by_name['UserRoleMapping'] = _USERROLEMAPPING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Policy = _reflection.GeneratedProtocolMessageType('Policy', (_message.Message,), {
  'DESCRIPTOR' : _POLICY,
  '__module__' : 'api.rbac_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.Policy)
  })
_sym_db.RegisterMessage(Policy)

Permission = _reflection.GeneratedProtocolMessageType('Permission', (_message.Message,), {
  'DESCRIPTOR' : _PERMISSION,
  '__module__' : 'api.rbac_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.Permission)
  })
_sym_db.RegisterMessage(Permission)

Role = _reflection.GeneratedProtocolMessageType('Role', (_message.Message,), {
  'DESCRIPTOR' : _ROLE,
  '__module__' : 'api.rbac_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.Role)
  })
_sym_db.RegisterMessage(Role)

UserRoleMapping = _reflection.GeneratedProtocolMessageType('UserRoleMapping', (_message.Message,), {
  'DESCRIPTOR' : _USERROLEMAPPING,
  '__module__' : 'api.rbac_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.UserRoleMapping)
  })
_sym_db.RegisterMessage(UserRoleMapping)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
